@@ -21,6 +21,7 @@
 package cmd
 
 import (
+	"errors"
 	"fmt"
 	"sort"
 	"strings"
@@ -36,8 +37,6 @@ import (
 	"go.k6.io/k6/output/influxdb"
 	"go.k6.io/k6/output/json"
 	"go.k6.io/k6/output/statsd"
-
-	"github.com/k6io/xk6-output-kafka/pkg/kafka"
 )
 
 // TODO: move this to an output sub-module after we get rid of the old collectors?
@@ -48,16 +47,13 @@ func getAllOutputConstructors() (map[string]func(output.Params) (output.Output,
 		"cloud":    cloud.New,
 		"influxdb": influxdb.New,
 		"kafka": func(params output.Params) (output.Output, error) {
-			params.Logger.Warn("The kafka output is deprecated, and will be removed in a future k6 version. " +
-				"Please use the new xk6 kafka output extension instead. " +
-				"It can be found at https://github.com/k6io/xk6-output-kafka.")
-			return kafka.New(params)
+			return nil, errors.New("the kafka output was deprecated in k6 v0.32.0 and removed in k6 v0.34.0, " +
+				"please use the new xk6 kafka output extension instead - https://github.com/k6io/xk6-output-kafka")
 		},
 		"statsd": statsd.New,
 		"datadog": func(params output.Params) (output.Output, error) {
-			params.Logger.Warn("The datadog output is deprecated, and will be removed in a future k6 version. " +
-				"Please use the statsd output with env variable K6_STATSD_ENABLE_TAGS=true instead.")
-			return statsd.NewDatadog(params)
+			return nil, errors.New("the datadog output was deprecated in k6 v0.32.0 and removed in k6 v0.34.0, " +
+				"please use the statsd output with env. variable K6_STATSD_ENABLE_TAGS=true instead")
 		},
 		"csv": csv.New,
 	}
@@ -76,6 +72,9 @@ func getAllOutputConstructors() (map[string]func(output.Params) (output.Output,
 func getPossibleIDList(constrs map[string]func(output.Params) (output.Output, error)) string {
 	res := make([]string, 0, len(constrs))
 	for k := range constrs {
+		if k == "kafka" || k == "datadog" {
+			continue
+		}
 		res = append(res, k)
 	}
 	sort.Strings(res)
